@@ -32,7 +32,7 @@ source file line with a 7 character wide prefix.  The prefix is one of
 You can produce such files with the Zope test runner by specifying
 ``--coverage`` on the command line.
 
-$Id: coveragereport.py 83302 2008-01-29 18:22:32Z srichter $
+$Id: coveragereport.py 85356 2008-04-14 18:38:52Z srichter $
 """
 __docformat__ = "reStructuredText"
 
@@ -242,7 +242,7 @@ def print_table_row(html, node, file_index):
 
 HEADER = """
     <html>
-      <head><title>Unit test coverage for %(name)s</title>
+      <head><title>Test coverage for %(name)s</title>
       <style type="text/css">
         a {text-decoration: none; display: block; padding-right: 1em;}
         a:hover {background: #EFA;}
@@ -251,7 +251,7 @@ HEADER = """
         .footer {margin: 2em; font-size: small; color: gray;}
       </style>
       </head>
-      <body><h1>Unit test coverage for %(name)s</h1>
+      <body><h1>Test coverage for %(name)s</h1>
       <table>
     """
 
@@ -375,13 +375,37 @@ def create_report_path(report_path):
         os.mkdir(report_path)
 
 
+def filter_fn(filename):
+    """Filter interesting coverage files.
+
+        >>> filter_fn('z3c.coverage.__init__.cover')
+        True
+        >>> filter_fn('z3c.coverage.tests.cover')
+        False
+        >>> filter_fn('z3c.coverage.tests.test_foo.cover')
+        False
+        >>> filter_fn('z3c.coverage.ftests.test_bar.cover')
+        False
+        >>> filter_fn('z3c.coverage.testing.cover')
+        True
+        >>> filter_fn('z3c.coverage.testname.cover')
+        True
+        >>> filter_fn('something-unrelated.txt')
+        False
+        >>> filter_fn('<doctest something-useless.cover')
+        False
+
+    """
+    parts = filename.split('.')
+    return (filename.endswith('.cover') and
+            not filename.startswith('<') and
+            'tests' not in parts and
+            'ftests' not in parts)
+
+
 def make_coverage_reports(path, report_path):
     """Convert reports from ``path`` into HTML files in ``report_path``."""
     create_report_path(report_path)
-    def filter_fn(filename):
-        return (filename.endswith('.cover') and
-                'test' not in filename and
-                not filename.startswith('<'))
     filelist = get_file_list(path, filter_fn)
     tree = create_tree(filelist, path)
     rev = get_svn_revision(os.path.join(path, os.path.pardir))
